@@ -7,6 +7,11 @@ Usage:
 Options:
   -h, --help        show this usage guide
   -v, --verbose     show verbose output
+
+By default, uranium will look for a uranium.yaml
+file in the current directory uranium was
+invoked in. this can be overridden by passing in a
+path to a <uranium_file>
 """
 from docopt import docopt
 from .uranium import Uranium
